@@ -1,3 +1,4 @@
+import logging
 from typing import Optional
 
 from core.position.Position import Position
@@ -11,19 +12,23 @@ from position.provider.supplier.PositionSupplier import PositionSupplier
 class PositionProvider:
 
     def __init__(self, position_supplier: PositionSupplier, position_repository: PositionRepository, position_slip_repository: PositionSlipRepository):
+        self.log = logging.getLogger(__name__)
         self.position_supplier = position_supplier
         self.position_repository = position_repository
         self.position_slip_repository = position_slip_repository
 
     def updating_position(self):
         position_slip = self.position_slip_repository.retrieve()
+        self.log.debug(f'Position Slip:[{position_slip}]')
         if position_slip is not None and position_slip.status is not Status.USED:
+            self.log.debug(f'USING the Position Slip:[{position_slip}]')
             self.obtain_position_based_on_non_used_slip(position_slip)
 
     def obtain_position_based_on_non_used_slip(self, position_slip):
         positions = self.position_supplier.get_positions()
         position = self.choose_position_based_on_slip(positions, position_slip)
         if position is not None:
+            self.log.debug(f'Position which is initiated from slip is now:[{position}]')
             self.use_position_slip(position_slip)
             self.position_repository.store(position)
 
